@@ -256,6 +256,8 @@ if CONFIG["CIRCE_ENABLE_WEB_UI"]:
             )
             signed = cookie_signer.sign(session_id)
             response.cookies["sess"] = signed.decode("UTF-8")
+            response.cookies["sess"]["httponly"] = True
+            response.cookies["sess"]["samesite"] = "Strict"
             return response
 
     @server.route("/upload/", methods=["POST", "GET"])
